@@ -2,7 +2,12 @@ from __future__ import generators
 from rdflib import BNode
 from rdflib.Literal import Literal
 from pprint import pprint
-from pysqlite2 import dbapi2
+try:
+    from pysqlite2 import dbapi2
+except ImportError:
+    import warnings
+    warnings.warn("pysqlite2 is not installed")
+    __test__=False
 import sha,sys,re,os
 from rdflib.term_utils import *
 from rdflib.Graph import QuotedGraph
